function A=lap1d(n,fun)
% A=lap1d(n,fun)
%
% generate 1-dimensional Laplacian operator for the problem 
% -(a(x)y')'=f in [0,1] and Dirichlet boundary cond. 
% use standard finite volume approach. 
%
% ---------------------------------------------------------
%
% Input
% -----
% fun    function a(x)
% n      size of the resulting system
% 
% ------------------------------------
%
% Output
% ------
% A      corresponding linear operator
h=1/(n+1);
omega=(1/2)*h:h:1;
a=feval(fun,omega);

% initialization, values will be overwritten, but the memory is allocated
A=sparse([],[],[],n,n,3*n-2);

A(1,1)=a(1);
for i=2:n
    A([i-1 i],[i-1 i])=A([i-1 i],[i-1 i]) + [a(i) -a(i);...
                                            -a(i)  a(i)];
end % for
A(n,n)=A(n,n)+a(n+1);
